( cd usr/lib ; rm -rf libpcre.so.0 )
( cd usr/lib ; ln -sf libpcre.so.0.0.1 libpcre.so.0 )
( cd usr/lib ; rm -rf libpcre.so )
( cd usr/lib ; ln -sf libpcre.so.0.0.1 libpcre.so )
( cd usr/lib ; rm -rf libpcreposix.so.0 )
( cd usr/lib ; ln -sf libpcreposix.so.0.0.0 libpcreposix.so.0 )
( cd usr/lib ; rm -rf libpcreposix.so )
( cd usr/lib ; ln -sf libpcreposix.so.0.0.0 libpcreposix.so )
( cd usr/lib ; rm -rf libpcrecpp.so.0 )
( cd usr/lib ; ln -sf libpcrecpp.so.0.0.0 libpcrecpp.so.0 )
( cd usr/lib ; rm -rf libpcrecpp.so )
( cd usr/lib ; ln -sf libpcrecpp.so.0.0.0 libpcrecpp.so )
